from nonebot import on_command
from nonebot.params import CommandArg
from nonebot.plugin import PluginMetadata
from nonebot.adapters.onebot.v11 import MessageSegment, Message, Bot, MessageEvent

from .Static.kuro_help import kuro_help
from .handler.pns_handlers.pns_data_handler import pns_data_handler
from .handler.pns_handlers.pns_login_handler import pns_login_handler, get_kuro_token

__plugin_meta__ = PluginMetadata(
    name="库洛游戏信息",
    description="一款库洛游戏角色信息插件",
    usage="发送“战双登录”注册，发送“战双”查询战双详情",
    type="application",
    homepage="https://github.com/ConcyWee/nonebot-plugin-kurogames",
    config=None,
    supported_adapters={"nonebot.adapters.onebot.v11"},
)


punishing = on_command("pns", aliases={"战双","战双详情"}, priority=5)
pns_login = on_command("pnslogin", aliases={"战双登陆","战双登录", "库洛登录", "库洛登陆", "鸣潮登录", "鸣潮登陆"}, priority=5)
pns_help  = on_command("pnshelp", aliases={"战双帮助", "库洛帮助", "鸣潮帮助"}, priority=5)


@pns_login.handle()
async def _(bot:Bot, event: MessageEvent, arg: Message = CommandArg()):
    user_id = event.get_user_id()
    data_content = arg.extract_plain_text()
    result = await pns_login_handler(user_id, data_content)
    await pns_login.finish(result)

@punishing.handle()
async def _(bot: Bot, event: MessageEvent):
    user_id = event.get_user_id()
    data_row = await get_kuro_token(user_id)
    if data_row:
        pic_result = await pns_data_handler(data_row)
        await punishing.finish(MessageSegment.image(pic_result))
    else:
        await punishing.finish("请先输入token")

@pns_help.handle()
async def _():
    help_datail = await kuro_help()
    await pns_help.finish(help_datail)


import sqlite3
from pathlib import Path
from contextlib import contextmanager
from nonebot import get_plugin_config
from  ..config import Config

plugin_config = get_plugin_config(Config)

KURO_DIR = plugin_config.KURO_DB_PATH
if isinstance(KURO_DIR, str):
    KURO_DIR = Path(KURO_DIR)
DATABASE = KURO_DIR / 'pns.db'

KURO_DIR.mkdir(parents=True, exist_ok=True)

class UserInfoManagement:
    _initialized = False
    def __init__(self):
        # 初始化数据库连接
        if not self._initialized:
            self.conn = sqlite3.connect(DATABASE)
            self._create_table_once()
            self._initialized = True
            print("数据库连接成功, 表已创建! ")
        else:
            self.conn = sqlite3.connect(DATABASE)
            print("数据库连接成功, 表已存在! ")

    @contextmanager
    def cursor(self):
        cur = self.conn.cursor()
        try:
            yield cur
        finally:
            cur.close()

    def close(self):
        self.conn.close()
        print("数据库关闭！")
    def _create_table_once(self):
        with self.cursor() as cur:
            cur.execute('''CREATE TABLE IF NOT EXISTS PNS_USER_INFO
                        (
                            bbs_id     INTEGER PRIMARY KEY,
                            qq_id      INTEGER,
                            pns_id     INTEGER,
                            mc_id      INTEGER,
                            user_token TEXT,
                            server_id  INTEGER
                        );''')
            self.conn.commit()
            return "success"
    def _get_data(self, qq_id):
        try:
            c = self.conn.cursor()
            sql = '''SELECT * FROM PNS_USER_INFO WHERE qq_id = ?'''
            c.execute(sql, (qq_id,))
            row = c.fetchone()
            return row
        except sqlite3.Error as e:
            raise e
        
    def _insert_data(self, user_id, data):
        bbs_id = data['userId']
        qq_id = user_id
        pns_id = data['pnsId']
        mc_id = data['mcId']
        user_token = data['token']
        server_id = data['serverId']
        try:
            c = self.conn.cursor()
            sql = '''INSERT INTO PNS_USER_INFO (bbs_id, qq_id, pns_id, mc_id, user_token, server_id) VALUES (?, ?, ?, ?, ?, ?)'''
            c.execute(sql, (bbs_id, qq_id, pns_id, mc_id, user_token, server_id))
            self.conn.commit()
            return "success"
        except Exception as e:
            raise e
        
    def _update_data(self, user_id, data):
        bbs_id = data['userId']
        qq_id = user_id
        pns_id = data['pnsId']
        mc_id = data['mcId']
        user_token = data['token']
        server_id = data['serverId']
        try:
            c = self.conn.cursor()
            params = (bbs_id, pns_id, mc_id, str(user_token), server_id, qq_id)
            sql = """UPDATE PNS_USER_INFO 
                    SET bbs_id = ?, pns_id = ?, mc_id = ?, 
                        user_token = ?, server_id = ? 
                    WHERE qq_id = ?"""

            c.execute(sql, params)
            self.conn.commit()
            return "success"
        except Exception as e:
            raise e
    
    def _getSpecificData(self, qq_id, field):
        try:
            c = self.conn.cursor()
            sql = '''SELECT {} FROM PNS_USER_INFO WHERE qq_id = ?'''.format(field)
            c.execute(sql, (qq_id,))
            row = c.fetchone()
            return row
        except Exception as e:
            raise e
        


            
